@@ -64,6 +64,7 @@ void DiceEdit::PreInit()
 
   table=new Lum::Table();
   table->SetFlex(true,true);
+  table->SetHeight(Lum::Base::Size::stdCharHeight,8);
   table->SetShowHeader(true);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
@@ -77,7 +78,9 @@ void DiceEdit::PreInit()
 
   horiz->Add(Lum::VPanel::Create(false,true)
              ->Add(Lum::Button::Create(_(L"BTN_ADD",L"_Add"),addAction,true,false))
+             ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_UPDATE",L"_Edit"),editAction,true,false))
+             ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
   SetMain(Lum::VPanel::Create(true,true)
