@@ -160,6 +160,10 @@ void GameArea::CalcAreaSize()
     return;
   }
 
+  //
+  // Calculate minimum cell size so that all texts can be displayed in full.
+  //
+
   std::list<DiceSet>::const_iterator iter=sets.begin();
 
   if (*currentSet>0) {
@@ -189,23 +193,77 @@ void GameArea::CalcAreaSize()
 
   std::cout << "Current cell size: " << cellSize << std::endl;
 
+  columns=0;
+
+  //
+  // Now place as many dices in one row as can be shown without horizontal scroll bar
+  // First make sure that we make the cells as big as possible without adding a vertical scrollbar.
+  //
+
+  size_t cellArea=0;
+
   for (size_t i=1; i<=iter->dices.size(); i++) {
     size_t w=(i+1)*distance+i*cellSize;
-    size_t j;
+    size_t r;
+    size_t c;
+    size_t aw;
+    size_t ah;
 
     if (w>width && i>1) {
       break;
     }
 
-    columns=i;
-    areaWidth=w;
+    c=i;
+    aw=w;
 
-    j=iter->dices.size()/i;
+    r=iter->dices.size()/i;
     if (iter->dices.size()%i>0) {
-      j++;
+      r++;
     }
 
-    areaHeight=(j+1)*distance+j*cellSize;
+    ah=(r+1)*distance+r*cellSize;
+
+    if (ah<=height) {
+      size_t cs;
+      size_t ca;
+
+      cs=std::min((width-(i+1)*distance)/i,(height-(r+1)*distance)/r);
+
+      ca=cs*cs*iter->dices.size();
+
+      if (ca>cellArea) {
+        columns=c;
+        cellSize=cs;
+        areaWidth=(i+1)*distance+i*cellSize;
+        areaHeight=(r+1)*distance+r*cellSize;
+      }
+    }
+  }
+
+  //
+  // If this does not work, place as many cells in a row as possible without showing
+  // a vertical scrollbar.
+  //
+
+  if (columns==0) {
+    for (size_t i=1; i<=iter->dices.size(); i++) {
+      size_t w=(i+1)*distance+i*cellSize;
+      size_t j;
+
+      if (w>width && i>1) {
+        break;
+      }
+
+      columns=i;
+      areaWidth=w;
+
+      j=iter->dices.size()/i;
+      if (iter->dices.size()%i>0) {
+        j++;
+      }
+
+      areaHeight=(j+1)*distance+j*cellSize;
+    }
   }
 }
 
